@@ -43,17 +43,18 @@ SWIFT_DEFAULT_USER=tester
 SWIFT_DEFAULT_USER_PWD=testing
 SWIFT_MEMBER_USER=tester_member
 SWIFT_MEMBER_USER_PWD=member
+SWIFT_DEFAULT_USER_DOMAIN_ID=${SWIFT_DEFAULT_USER_DOMAIN_ID:-default}
+SWIFT_DEFAULT_PROJECT_DOMAIN_ID=${SWIFT_DEFAULT_PROJECT_DOMAIN_ID:-default}
 
 SWIFT_CONF_DIR=${SWIFT_CONF_DIR:-/etc/swift}
 
 # Storlets install tunables
-STORLETS_DEFAULT_USER_DOMAIN_ID=${STORLETS_DEFAULT_USER_DOMAIN_ID:-default}
-STORLETS_DEFAULT_PROJECT_DOMAIN_ID=${STORLETS_DEFAULT_PROJECT_DOMAIN_ID:-default}
 STORLETS_DOCKER_DEVICE=${STORLETS_DOCKER_DEVICE:-/var/lib/storlets}
 if is_fedora; then
     STORLETS_DOCKER_BASE_IMG=${STORLETS_DOCKER_BASE_IMG:-quay.io/centos/centos:stream9}
 else
-    STORLETS_DOCKER_BASE_IMG=${STORLETS_DOCKER_BASE_IMG:-ubuntu:22.04}
+    ubuntu_version=$(source /etc/os-release ; echo $VERSION_ID)
+    STORLETS_DOCKER_BASE_IMG=${STORLETS_DOCKER_BASE_IMG:-ubuntu:$ubuntu_version}
 fi
 STORLETS_SWIFT_RUNTIME_USER=${STORLETS_SWIFT_RUNTIME_USER:-$USER}
 STORLETS_SWIFT_RUNTIME_GROUP=${STORLETS_SWIFT_RUNTIME_GROUP:-$USER}
@@ -72,56 +73,36 @@ STORLETS_RESTART_CONTAINER_TIMEOUT=${STORLETS_RESTART_CONTAINER_TIMEOUT:-3}
 STORLETS_RUNTIME_TIMEOUT=${STORLETS_RUNTIME_TIMEOUT:-40}
 STORLETS_JDK_VERSION=${STORLETS_JDK_VERSION:-11}
 
+STORLETS_BIN_DIR=$(get_python_exec_prefix)
+
 TMP_REGISTRY_PREFIX=/tmp/registry
 
 # Functions
 # ---------
 
-function _export_os_vars {
-    export OS_IDENTITY_API_VERSION=3
-    export OS_AUTH_URL="http://$KEYSTONE_IP/identity/v3"
-    export OS_REGION_NAME=RegionOne
-}
-
-function _export_keystone_os_vars {
-    _export_os_vars
-    export OS_USERNAME=$ADMIN_USER
-    export OS_USER_DOMAIN_ID=$STORLETS_DEFAULT_USER_DOMAIN_ID
-    export OS_PASSWORD=$ADMIN_PASSWORD
-    export OS_PROJECT_NAME=$ADMIN_USER
-    export OS_PROJECT_DOMAIN_ID=$STORLETS_DEFAULT_PROJECT_DOMAIN_ID
-}
-
 function _export_swift_os_vars {
-    _export_os_vars
+    export OS_IDENTITY_API_VERSION=3
+    export OS_AUTH_URL=$KEYSTONE_SERVICE_URI
+    export OS_REGION_NAME=$REGION_NAME
     export OS_USERNAME=$SWIFT_DEFAULT_USER
-    export OS_USER_DOMAIN_ID=$STORLETS_DEFAULT_USER_DOMAIN_ID
+    export OS_USER_DOMAIN_ID=$SWIFT_DEFAULT_USER_DOMAIN_ID
     export OS_PASSWORD=$SWIFT_DEFAULT_USER_PWD
     export OS_PROJECT_NAME=$SWIFT_DEFAULT_PROJECT
-    export OS_PROJECT_DOMAIN_ID=$STORLETS_DEFAULT_PROJECT_DOMAIN_ID
+    export OS_PROJECT_DOMAIN_ID=$SWIFT_DEFAULT_PROJECT_DOMAIN_ID
 }
 
 function configure_swift_and_keystone_for_storlets {
     # Add project and users to Keystone
-    _export_keystone_os_vars
-    project_test_created=$(openstack project list | grep -w $SWIFT_DEFAULT_PROJECT | wc -l)
-    if [ $project_test_created -eq 0 ]; then
-        openstack project create $SWIFT_DEFAULT_PROJECT
-    fi
-    user_tester_created=$(openstack user list | grep -w $SWIFT_DEFAULT_USER | wc -l)
-    if [ $user_tester_created -eq 0 ]; then
-        openstack user create --project $SWIFT_DEFAULT_PROJECT --password $SWIFT_DEFAULT_USER_PWD $SWIFT_DEFAULT_USER
-        openstack role add --user $SWIFT_DEFAULT_USER --project $SWIFT_DEFAULT_PROJECT admin
-    fi
-    member_user_tester_created=$(openstack user list | grep -w $SWIFT_MEMBER_USER | wc -l)
-    if [ $member_user_tester_created -eq 0 ]; then
-        role_member_created=$(openstack role list | grep -w _member_ | wc -l)
-        if [ $role_member_created -eq 0 ]; then
-            openstack role create _member_
-        fi
-        openstack user create --project $SWIFT_DEFAULT_PROJECT --password $SWIFT_MEMBER_USER_PWD $SWIFT_MEMBER_USER
-        openstack role add --user $SWIFT_MEMBER_USER --project $SWIFT_DEFAULT_PROJECT _member_
-    fi
+    get_or_create_project $SWIFT_DEFAULT_PROJECT $SWIFT_DEFAULT_PROJECT_DOMAIN_ID
+    get_or_create_user $SWIFT_DEFAULT_USER $SWIFT_DEFAULT_USER_PWD \
+        $SWIFT_DEFAULT_USER_DOMAIN_ID
+    get_or_add_user_project_role admin $SWIFT_DEFAULT_USER $SWIFT_DEFAULT_PROJECT \
+        $SWIFT_DEFAULT_USER_DOMAIN_ID $SWIFT_DEFAULT_PROJECT_DOMAIN_ID
+
+    get_or_create_user $SWIFT_MEMBER_USER $SWIFT_MEMBER_USER_PWD \
+        $SWIFT_DEFAULT_USER_DOMAIN_ID
+    get_or_add_user_project_role anotherrole $SWIFT_MEMBER_USER $SWIFT_DEFAULT_PROJECT \
+        $SWIFT_DEFAULT_USER_DOMAIN_ID $SWIFT_DEFAULT_PROJECT_DOMAIN_ID
 
     # Modify relevant Swift configuration files
     _modify_swift_conf
@@ -130,21 +111,27 @@ function configure_swift_and_keystone_for_storlets {
     # Create storlet related containers and set ACLs
     start_swift
     _export_swift_os_vars
-    swift post --meta "Storlet-Enabled:True"
-    swift post --read-acl $SWIFT_DEFAULT_PROJECT:$SWIFT_MEMBER_USER $STORLETS_STORLET_CONTAINER_NAME
-    swift post --read-acl $SWIFT_DEFAULT_PROJECT:$SWIFT_MEMBER_USER $STORLETS_DEPENDENCY_CONTAINER_NAME
-    swift post $STORLETS_LOG_CONTAIER_NAME
+    ${STORLETS_BIN_DIR}/swift post --meta "Storlet-Enabled:True"
+    ${STORLETS_BIN_DIR}/swift post \
+        --read-acl $SWIFT_DEFAULT_PROJECT:$SWIFT_MEMBER_USER \
+        $STORLETS_STORLET_CONTAINER_NAME
+    ${STORLETS_BIN_DIR}/swift post \
+        --read-acl $SWIFT_DEFAULT_PROJECT:$SWIFT_MEMBER_USER \
+        $STORLETS_DEPENDENCY_CONTAINER_NAME
+    ${STORLETS_BIN_DIR}/swift post $STORLETS_LOG_CONTAIER_NAME
 }
 
 function _install_docker {
     if is_fedora; then
         # NOTE(tkajinam): install_docker.sh requires the yum command
-        sudo dnf install -y yum
+        install_package yum
+        wget http://get.docker.com -O install_docker.sh
+        chmod 755 install_docker.sh
+        sudo bash -x install_docker.sh
+        rm install_docker.sh
+    else
+        install_package docker.io
     fi
-    wget http://get.docker.com -O install_docker.sh
-    chmod 755 install_docker.sh
-    sudo bash -x install_docker.sh
-    rm install_docker.sh
 
     # Add swift user to docker group so that the user can manage docker
     # containers without sudo
@@ -168,7 +155,8 @@ function prepare_storlets_install {
     _install_docker
 
     if is_fedora; then
-        install_package java-${STORLETS_JDK_VERSION}-openjdk-devel ant
+        install_package java-${STORLETS_JDK_VERSION}-openjdk-devel \
+            ant-openjdk${STORLETS_JDK_VERSION} ant
         install_package python3 python3-devel
     else
         install_package openjdk-${STORLETS_JDK_VERSION}-jdk-headless ant
@@ -184,7 +172,8 @@ function _generate_jre_dockerfile {
 FROM $STORLETS_DOCKER_BASE_IMG
 MAINTAINER root
 RUN dnf install ${PYTHON_PACKAGES} ${JDK_PACKAGE} util-linux-core -y && \
-    dnf clean all
+    dnf clean all && \
+    rm -rf /var/cache/dnf
 EOF
     else
         JDK_PACKAGE="openjdk-${STORLETS_JDK_VERSION}-jdk-headless"
@@ -193,8 +182,9 @@ EOF
 FROM $STORLETS_DOCKER_BASE_IMG
 MAINTAINER root
 RUN apt-get update && \
-    apt-get install ${PYTHON_PACKAGES} ${JDK_PACKAGE} -y && \
-    apt-get clean
+    apt-get install -y ${PYTHON_PACKAGES} ${JDK_PACKAGE} && \
+    apt-get clean && \
+    rm -rf /var/lib/apt/lists/*
 EOF
     fi
 }
@@ -209,35 +199,6 @@ function create_base_jre_image {
     cd -
 }
 
-function create_logback_xml {
-    sudo tee /usr/local/lib/storlets/logback.xml <<EOF >/dev/null
-<configuration>
-  <appender name="FILE" class="ch.qos.logback.core.rolling.RollingFileAppender">
-    <file>/tmp/SDaemon.log</file>
-    <rollingPolicy class="ch.qos.logback.core.rolling.TimeBasedRollingPolicy">
-            <!-- daily rollover. Make sure the path matches the one in the file element or else
-             the rollover logs are placed in the working directory. -->
-            <fileNamePattern>/srv/logs/application_%d{yyyy-MM-dd}.%i.log</fileNamePattern>
-
-            <timeBasedFileNamingAndTriggeringPolicy class="ch.qos.logback.core.rolling.SizeAndTimeBasedFNATP">
-                <maxFileSize>1MB</maxFileSize>
-            </timeBasedFileNamingAndTriggeringPolicy>
-            <!-- keep 30 days' worth of history -->
-            <maxHistory>30</maxHistory>
-    </rollingPolicy>
-    <encoder>
-        <pattern>%-4relative [%thread] %-5level %logger{35} - %msg%n</pattern>
-    </encoder>
-  </appender>
-
-  <root level="TRACE">
-    <appender-ref ref="FILE" />
-  </root>
-</configuration>
-EOF
-    sudo chmod 0744 /usr/local/lib/storlets/logback.xml
-}
-
 function install_storlets_code {
     echo "Installing storlets"
     cd $REPO_DIR
@@ -252,12 +213,10 @@ function install_storlets_code {
     # from docker container.
     sudo mkdir -p -m 755 /usr/local/lib/storlets/python
 
-    # NOTE(takashi): We need --no-deps to avoid enum34 installed in py 2 env,
-    #                which causes failure in py3 execution.
-    pip_install . -t /usr/local/lib/storlets/python --no-compile --no-deps
+    GLOBAL_VENV=False pip_install . -t /usr/local/lib/storlets/python --no-compile --no-deps
     sudo mkdir -p -m 755 /usr/local/libexec/storlets
     for bin_file in storlets-daemon storlets-daemon-factory ; do
-        sudo cp `which ${bin_file}` /usr/local/libexec/storlets/
+        sudo cp ./bin/${bin_file} /usr/local/libexec/storlets/
     done
 
     sudo mkdir -p -m 0755 $STORLETS_DOCKER_DEVICE
@@ -341,7 +300,7 @@ function create_default_tenant_image {
 
 function create_test_config_file {
     testfile=${REPO_DIR}/test.conf
-    iniset ${testfile} general keystone_default_domain $STORLETS_DEFAULT_PROJECT_DOMAIN_ID
+    iniset ${testfile} general keystone_default_domain $SWIFT_DEFAULT_PROJECT_DOMAIN_ID
     iniset ${testfile} general keystone_public_url $KEYSTONE_PUBLIC_URL
     iniset ${testfile} general storlets_default_project_name $SWIFT_DEFAULT_PROJECT
     iniset ${testfile} general storlets_default_project_user_name $SWIFT_DEFAULT_USER
@@ -365,9 +324,6 @@ function install_storlets {
     create_base_jre_image
     create_default_tenant_image
 
-    echo "Create logback xml file"
-    create_logback_xml
-
     echo "Create test configuration file"
     create_test_config_file
 
