@@ -4,12 +4,9 @@
 #
 # NOTE: The libraries are currently installed under /usr/lib/storlets
 #       so you may need root privilege to execute this script
+set -x
 
-# build scripts
-cd scripts
-# TODO(takashi): also install them
-make
-cd -
+STORLETS_JDK_VERSION=${STORLETS_JDK_VERSION:-11}
 
 # install c library
 cd src/c/sbus
@@ -17,13 +14,4 @@ make && make install
 cd -
 
 # Install java library
-ant install
-
-# Install container side scripts
-SRC=bin
-DST=/usr/local/libexec/storlets
-mkdir -p $DST
-chmod 755 $DST
-cp "$SRC/init_container.sh" $DST
-cp "$SRC/storlets-daemon" $DST
-cp "$SRC/storlets-daemon-factory" $DST
+STORLETS_JDK_VERSION=${STORLETS_JDK_VERSION} ant install
