@@ -12,12 +12,13 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import mock
+import json
 import unittest
+from unittest import mock
 
 from storlets.sbus import command as sbus_cmd
 from storlets.sbus.file_description import SBUS_FD_SERVICE_OUT
-from storlets.sbus.datagram import FDMetadata, SBusServiceDatagram
+from storlets.sbus.datagram import SBusFileDescriptor, SBusServiceDatagram
 from storlets.agent.common.server import EXIT_SUCCESS, command_handler, \
     CommandResponse, CommandFailure, CommandSuccess, SBusServer
 from tests.unit import FakeLogger
@@ -29,15 +30,28 @@ class TestCommandResponse(unittest.TestCase):
         self.assertTrue(resp.status)
         self.assertEqual('ok', resp.message)
         self.assertTrue(resp.iterable)
+        self.assertIsNone(resp.task_id)
 
         resp = CommandResponse(False, 'error', False)
         self.assertFalse(resp.status)
         self.assertEqual('error', resp.message)
         self.assertFalse(resp.iterable)
+        self.assertIsNone(resp.task_id)
+
+        resp = CommandResponse(True, 'ok', task_id='foo')
+        self.assertTrue(resp.status)
+        self.assertEqual('ok', resp.message)
+        self.assertTrue(resp.iterable)
+        self.assertEqual('foo', resp.task_id)
 
     def test_report_message(self):
         resp = CommandResponse(True, 'msg', True)
-        self.assertEqual('True: msg', resp.report_message)
+        self.assertEqual({'status': True, 'message': 'msg'},
+                         json.loads(resp.report_message))
+
+        resp = CommandResponse(True, 'msg', True, 'foo')
+        self.assertEqual({'status': True, 'message': 'msg', 'task_id': 'foo'},
+                         json.loads(resp.report_message))
 
 
 class TestCommandSuccess(unittest.TestCase):
@@ -100,7 +114,7 @@ def create_fake_sbus_class(scenario):
     """
     class FakeSBus(object):
         """
-        Fake SBus communication according feeded scenario.
+        Fake SBus communication according fed scenario.
         The scenario must be ordered by calls
         """
         def __init__(self):
@@ -122,7 +136,7 @@ def create_fake_sbus_class(scenario):
                     "for SBus but %d is expected" % (command, ret_val[0]))
             return ret_val[1]
 
-        def listen(self, fd):
+        def listen(self, fd, timeout=0):
             return self._get_fake_response('listen', fd)
 
         def command(self):
@@ -148,12 +162,11 @@ class TestSBusServerMain(unittest.TestCase):
         self.server = self._get_test_server()
 
     def _test_main_loop_stop(self, stop_command):
-        metadata = [FDMetadata(SBUS_FD_SERVICE_OUT).to_dict()]
+        sfds = [SBusFileDescriptor(SBUS_FD_SERVICE_OUT, 1)]
         scenario = [
             ('create', 1),
             ('listen', 1),
-            ('receive', SBusServiceDatagram(command=stop_command, fds=[1],
-                                            metadata=metadata,
+            ('receive', SBusServiceDatagram(command=stop_command, sfds=sfds,
                                             params=None, task_id=None)),
         ]
 
@@ -167,6 +180,24 @@ class TestSBusServerMain(unittest.TestCase):
         self.assertEqual([], self.logger.get_log_lines('error'))
         self.assertEqual([], self.logger.get_log_lines('warn'))
 
+    def _test_main_loop_timeout(self):
+        scenario = [
+            ('create', 1),
+            ('listen', 0),
+            ('listen', 0),
+            ('listen', 0),
+            ('listen', 0)
+        ]
+
+        self.server.listen_timeout = self.server.loop_timeout * 4
+
+        fake_sbus_class = create_fake_sbus_class(scenario)
+        with mock.patch('storlets.agent.common.server.SBus', fake_sbus_class):
+            with mock.patch('os.fdopen'):
+                ret = self.server.main_loop()
+
+        self.assertEqual(EXIT_SUCCESS, ret)
+
 
 if __name__ == '__main__':
     unittest.main()
