@@ -13,10 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
 import unittest
+from unittest import mock
 
-from storlets.gateway.gateways.stub import StorletGatewayStub
+from storlets.gateway.gateways.stub import StubStorletGateway
 from storlets.swift_middleware import storlet_handler
 
 from tests.unit import FakeLogger
@@ -25,13 +25,14 @@ from tests.unit.swift_middleware import FakeApp
 
 def create_handler_config(exec_server):
     return {'execution_server': exec_server,
-            'gateway_module': StorletGatewayStub}
+            'gateway_module': StubStorletGateway}
 
 
 class BaseTestStorletMiddleware(unittest.TestCase):
     def setUp(self, exec_server='proxy'):
         self.exec_server = exec_server
         self.conf = create_handler_config(exec_server)
+        self.logger = FakeLogger()
         self.base_app = FakeApp()
 
     def tearDown(self):
@@ -39,9 +40,8 @@ class BaseTestStorletMiddleware(unittest.TestCase):
 
     def get_app(self, app, global_conf, **local_conf):
         with mock.patch('storlets.swift_middleware.storlet_handler.'
-                        'get_logger') as \
-            get_fake_logger:
-            get_fake_logger.return_value = FakeLogger()
+                        'get_logger') as get_fake_logger:
+            get_fake_logger.return_value = self.logger
             factory = storlet_handler.filter_factory(global_conf, **local_conf)
             return factory(app)
 
