@@ -13,10 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
-import unittest
 from contextlib import contextmanager
-from six import StringIO
+from io import StringIO
+import unittest
+from unittest import mock
 
 from swift.common.swob import Request
 from storlets.gateway.common.exceptions import FileManagementError
@@ -200,8 +200,8 @@ class TestStorletBaseHandler(unittest.TestCase):
                 req, mock.MagicMock(), mock.MagicMock(),
                 mock.MagicMock(), mock.MagicMock())
             handler._update_storlet_parameters_from_headers()
-            self.assertEqual(handler.request.params['1'], '2:3:4')
-            self.assertEqual(handler.request.params['A'], 'c')
+            self.assertEqual('2:3:4', handler.request.params['1'])
+            self.assertEqual('c', handler.request.params['A'])
 
 
 if __name__ == '__main__':
